@@ -1,6 +1,25 @@
-#--------------------------------------------------------------
+##############################################################################
+#    Copyright (c) 2012-2016 Russell V. Lenth                                #
+#                                                                            #
+#    This file is part of the lsmeans package for R (*lsmeans*)              #
+#                                                                            #
+#    *lsmeans* is free software: you can redistribute it and/or modify       #
+#    it under the terms of the GNU General Public License as published by    #
+#    the Free Software Foundation, either version 2 of the License, or       #
+#    (at your option) any later version.                                     #
+#                                                                            #
+#    *lsmeans* is distributed in the hope that it will be useful,            #
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
+#    GNU General Public License for more details.                            #
+#                                                                            #
+#    You should have received a copy of the GNU General Public License       #
+#    along with R and *lsmeans*.  If not, see                                #
+#    <https://www.r-project.org/Licenses/> and/or                            #
+#    <http://www.gnu.org/licenses/>.                                         #
+##############################################################################
+
 ### support for the ordinal package
-# (initial setup thanks to Maxime Herve, RVAideMemoire package)
 
 recover.data.clm = function(object, mode = "latent", ...) {
     if (!is.na(pmatch(mode, "scale"))) {
@@ -12,8 +31,8 @@ recover.data.clm = function(object, mode = "latent", ...) {
         recover.data.lm(object, ...)
     else { # bring-in predictors from loc, scale, and nom models
         trms = delete.response(object$terms)
-        #preds = union(All.vars(trms), union(All.vars(object$S.terms), All.vars(object$nom.terms)))
-        x.preds = union(All.vars(object$S.terms), All.vars(object$nom.terms))
+        #preds = union(.all.vars(trms), union(.all.vars(object$S.terms), .all.vars(object$nom.terms)))
+        x.preds = union(.all.vars(object$S.terms), .all.vars(object$nom.terms))
         #x.trms = update(trms, reformulate(preds))
         x.trms = terms(update(trms, reformulate(c(".", x.preds))))
         recover.data(object$call, x.trms, object$na.action, ...)
@@ -279,7 +298,7 @@ lsm.basis.clm = function (object, trms, xlev, grid,
     if (!is.null(object@grid$.offset.))
         eta = eta + object@grid$.offset.
     for (j in scols) linfct[, j] = eta * linfct[, j]
-    linfct = (diag(rsigma) %*% linfct) [, active, drop = FALSE]
+    linfct = (.diag(rsigma) %*% linfct) [, active, drop = FALSE]
     list(est = eta * rsigma, V = linfct %*% tcrossprod(object@V, linfct))
 }
 
