@@ -1,3 +1,24 @@
+##############################################################################
+#    Copyright (c) 2012-2016 Russell V. Lenth                                #
+#                                                                            #
+#    This file is part of the lsmeans package for R (*lsmeans*)              #
+#                                                                            #
+#    *lsmeans* is free software: you can redistribute it and/or modify       #
+#    it under the terms of the GNU General Public License as published by    #
+#    the Free Software Foundation, either version 2 of the License, or       #
+#    (at your option) any later version.                                     #
+#                                                                            #
+#    *lsmeans* is distributed in the hope that it will be useful,            #
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
+#    GNU General Public License for more details.                            #
+#                                                                            #
+#    You should have received a copy of the GNU General Public License       #
+#    along with R and *lsmeans*.  If not, see                                #
+#    <https://www.r-project.org/Licenses/> and/or                            #
+#    <http://www.gnu.org/licenses/>.                                         #
+##############################################################################
+
 # Reference grid code
 
 
@@ -322,6 +343,8 @@ ref.grid <- function(object, at, cov.reduce = mean, mult.name, mult.levs,
 # have been coerced to factors. And also which factors have been coerced
 # to be covariates
 .find.coerced = function(trms, data) {
+    if (ncol(data) == 0) 
+        return(list(factors = integer(0), covariates = integer(0)))
     isfac = sapply(data, function(x) inherits(x, "factor"))
     
     # Character vectors of factors and covariates in the data...
